@@ -395,6 +395,7 @@ def apply(for_real, send_mail, random):
         if policies:
             result[product.name] = policies
     if result:
+        # variables declared for report purposes
         message = ''
         dataset_statistics = tablib.Dataset()
         dataset_statistics.headers = [
@@ -425,12 +426,22 @@ def apply(for_real, send_mail, random):
             'status',
             'date'
             ]
+
+        # loop over the products to fetch their limitation policies
         products = sorted([i for i in result], reverse=True)
         for product in products:
+            click.echo(
+                "===========================================================\n"
+                "Product '{}'\n"
+                "===========================================================\n"
+                .format(product)
+            )
             policies = result[product]
             message += 'Produit: {product}\n'.format(product=product)
             number_fup_in = 0
             number_fup_out = 0
+
+            # loop over each policies to get affected customers
             for policy in policies:
                 message += (
                     '\n'
@@ -441,7 +452,19 @@ def apply(for_real, send_mail, random):
                 foo = ''
                 fup_true = 0
                 total_client = len(policy['customers'])
+                click.echo(
+                    "-------------------------------------------------------\n"
+                    "Data limitation: {}Go"
+                    "Affected customers: {}"
+                    "-------------------------------------------------------\n"
+                    .format(policy['data_limit'], total_client)
+                )
+
                 for customer, data in policy['customers'].items():
+                    click.echo("Customer '{}':".format(customer))
+
+                    # checks that the customer has a business product that can
+                    # be FUP-ed
                     customer_policies_status = Customer(customer).fup_status
                     policy_status = False
                     customer_policy_status = customer_policies_status.get(
@@ -454,6 +477,12 @@ def apply(for_real, send_mail, random):
                             reverse=True
                             )
                         policy_status = customer_policy_status[0]['status']
+
+                    click.echo(
+                        "> product can be FUP-ed: {}".format(policy_status)
+                    )
+
+                    # Fetches the customer's consumption
                     conso = {
                         'internet': {'octets_in': 0, 'octets_out': 0},
                         'national': {'octets_in': 0, 'octets_out': 0},
@@ -473,6 +502,12 @@ def apply(for_real, send_mail, random):
                     total_octets_in = str_data(data['octets_in'])
                     total_octets_out = str_data(data['octets_out'])
                     total = str_data(data['total'])
+
+                    click.echo(
+                        "> Last 30days consumption: IN={} OUT={} TOTAL={}"
+                        .format(total_octets_in, total_octets_out, total)
+                    )
+
                     dataset.append(
                         [
                             product,
@@ -488,16 +523,24 @@ def apply(for_real, send_mail, random):
                             datetime.now().date().strftime('%d/%m/%Y')
                             ]
                         )
+
+                    # products that can be fup-ed
                     if policy_status is True:
                         fup_true += 1
+
+                    # decides if the product is fup-ed or not
                     if data.get('fup_in'):
                         number_fup_in = number_fup_in + 1
                         status = 'fup_in'
+                        click.echo('> customer will be FUP-ed')
                     elif data.get('fup_out'):
                         status = 'fup_out'
                         number_fup_out = number_fup_out + 1
+                        click.echo('> customer will be DEFUP-ed')
                     else:
                         status = None
+                        click.echo('> [!] unknown fup status')
+
                     if status:
                         foo += (
                             ' - {customer}: {total} Go ({status})\n'.format(
@@ -509,13 +552,30 @@ def apply(for_real, send_mail, random):
                 if foo:
                     message += foo
                 else:
+                    click.echo("[!] No FUP-ed customer\n")
                     message += "Aucun client à FUPer\n"
+
+                # prevents division by O when calculating %s
                 if total_client == 0:
                     total_client = 1
+
+                # Calculates percentages for fup/defup report
                 fup_false = total_client - fup_true
                 pourcentage_fup = fup_true * 100 / total_client
                 pourcentage_fup = round(pourcentage_fup)
+                click.echo(
+                    "\n"
+                    "FUP-ed: {fup}/{total} ({fup_per}%) "
+                    "DEFUP-ed:{defup}/{total}\n"
+                    .format(
+                        fup=fup_true,
+                        defup=fup_false,
+                        fup_per=pourcentage_fup,
+                        total=total_client
+                    )
+                )
                 pourcentage_fup = '{}%'.format(pourcentage_fup)
+
                 dataset_synthesis.append(
                     [
                         policy['name'],
@@ -534,6 +594,7 @@ def apply(for_real, send_mail, random):
                     ]
                 )
             message += '\n\n\n'
+
         message += str(dataset_statistics)
         message += '\n\n\n'
         message += str(dataset_synthesis)
@@ -544,8 +605,13 @@ def apply(for_real, send_mail, random):
             synthesis=dataset_synthesis
             )
         click.echo(message)
+
+        # writes the fup/defup report to a csv
         with open('/tmp/details.csv', 'w') as f:
             f.write(dataset.export('csv', delimiter=';'))
+        click.echo("Final report saved in '/tmp/details.csv'")
+
+        # sends the fup/defup report
         if send_mail:
             recipients = CONFIG['ALERT']['to']
             content_text = MIMEText(message, 'plain', 'utf-8')
@@ -576,6 +642,8 @@ def apply(for_real, send_mail, random):
                 msg.as_string()
                 )
             s.quit()
+            click.echo("Report email sent to '{}'".format(msg['To']))
+    click.echo("DONE")
 
 
 @cmd.command()
