@@ -254,13 +254,12 @@ class Customer(object):
                 "[FUP/DEFUP] Customer {} {operation} from Aiguiller: "
                 "api request: {}, "
                 "parameters: {}, "
-                "response: {} {}"
+                "response: {}"
                 .format(
                     self.name,
                     api_request,
                     params,
                     response,
-                    response.text,
                     operation=msg,
                 )
             )
