@@ -144,13 +144,23 @@ class Product(object):
 
     def get_customers_aiguillier(self):
         """Récupération de la liste de clients depuis aiguillier"""
-        response = REST_CLIENT.get(
-            '/fup',
-            auth=(
-                CONFIG['AIGUILLIER']['username'],
-                CONFIG['AIGUILLIER']['password']
-                ),
-            params={'product': self.name}
+        try:
+            response = REST_CLIENT.get(
+                '/fup',
+                auth=(
+                    CONFIG['AIGUILLIER']['username'],
+                    CONFIG['AIGUILLIER']['password']
+                    ),
+                params={'product': self.name}
+                )
+        except Exception as e:
+            LOGS.logger.error(
+                "Unable to fetch customers from Aiguillier: {}"
+                .format(str(e))
+            )
+            core.send_error_report(
+                "Customers synchronization from Aiguillier",
+                str(e)
             )
         customers = response['content'].get('customers', [])
         customers = {
@@ -296,13 +306,24 @@ class Product(object):
                                     )
                                 if status[0]['status']:
                                     # si le client était fup, il faut le défup
-                                    response = REST_CLIENT.delete(
-                                        '/fup',
-                                        auth=(
-                                            CONFIG['AIGUILLIER']['username'],
-                                            CONFIG['AIGUILLIER']['password']
-                                            ),
-                                        params={'customer': self.name}
+                                    login = CONFIG['AIGUILLIER']['username']
+                                    mdp = CONFIG['AIGUILLIER']['password']
+                                    try:
+                                        response = REST_CLIENT.delete(
+                                            '/fup',
+                                            auth=(login, mdp),
+                                            params={'customer': self.name}
+                                            )
+                                    except Exception as e:
+                                        LOGS.logger.error(
+                                            "Unable to DEFUP customer {} from "
+                                            "Aiguillier: {}"
+                                            .format(self.name, str(e))
+                                        )
+                                        core.send_error_report(
+                                            "DEFUP customer {} from "
+                                            "Aiguillier".format(self.name),
+                                            str(e)
                                         )
                                     LOGS.logger.info(
                                         "[DEFUP] Removing customer {} "
